@@ -4,7 +4,7 @@ Created on 2020-11-9
 
 @author: zhys513(254851907@qq.com)
 '''
-from opspipe.reg.scanner import regularExtrator
+from opspipe.reg.scanner import RegularExtrator
 from unittest import TestCase 
 import unittest
 
@@ -13,7 +13,7 @@ text = '急寻特朗普，男孩，于2018年11月27号11时在陕西省安康
 class TestMain(TestCase):
     
     def test_scan_for_lists_p(self): 
-        ex = regularExtrator(text)  
+        ex = RegularExtrator(text)  
         ex.split_txt('，')
         ex.scan_for_lists_p(r'\d{6}') 
         ex.print_list()  
