@@ -30,7 +30,7 @@ class LoggerFactory:
         'error': logging.ERROR,
     }
 
-    def __init__(self, filename, when='D', back_count=3,
+    def __init__(self, filename='log', when='D', back_count=3,
                  fmt='[%(levelname)s] - %(asctime)s - process: %(process)d - %(name)s：%(lineno)d - %(message)s'):
         """
         保存日志
